// generated from rosidl_adapter/resource/msg.idl.em
// with input from visualization_msgs/msg/InteractiveMarkerPose.msg
// generated code does not contain a copyright notice

#include "geometry_msgs/msg/Pose.idl"
#include "std_msgs/msg/Header.idl"

module visualization_msgs {
  module msg {
    struct InteractiveMarkerPose {
      @verbatim (language="comment", text=
        "Time/frame info.")
      std_msgs::msg::Header header;

      @verbatim (language="comment", text=
        "Initial pose. Also, defines the pivot point for rotations.")
      geometry_msgs::msg::Pose pose;

      @verbatim (language="comment", text=
        "Identifying string. Must be globally unique in" "\n"
        "the topic that this message is sent through.")
      string name;
    };
  };
};
